<?php
/**
 *ipushs的功能和定義
 *
 *設定的主題，並提供了一些輔助功能。一些輔助功能
 *使用自定義模板標籤的主題。其他附加行動
 *過濾鉤子在WordPress改變的核心功能。
 *
 *第一個功能，ipushs_setup（），設立登記支持主題
 *各種功能，如後縮略圖，導航菜單，在WordPress。
 *
 *當使用一個子主題（見http://codex.wordpress.org/Theme_Development和
 * http://codex.wordpress.org/Child_Themes），您可以重寫某些功能
 *（那些包裹在function_exists（）調用）在您的孩子主題的第一定義
 * functions.php文件。兒童主題的functions.php文件包括前父
 *主題的文件，使孩子的主題功能將被使用。
 *
 *不可插拔（不裹在function_exists（））的功能，而不是附加
 *一個過濾器或行動掛鉤。可以去掉鉤，使用remove_action（）或
 * remove_filter（），你可以將自己的鉤子函數。
 *
 *我們可以刪除父主題的鉤後，才連接，這意味著我們需要
 *等到設立兒童主題：
 *
 * <code>
 * add_action( 'after_setup_theme', 'my_child_theme_setup' );
 * function my_child_theme_setup() {
 *     // We are providing our own filter for excerpt_length (or using the unfiltered value)
 *     remove_filter( 'excerpt_length', 'ipushs_excerpt_length' );
 *     ...
 * }
 * </code>
 *
 * 對於掛鉤，行動和過濾器的更多信息，請參閱http://codex.wordpress.org/Plugin_API。
 *
 * @package WordPress
 * @subpackage ipushs
 * @since ipushs 1.0
 */


/**
 * Tell WordPress to run ipushs_setup() when the 'after_setup_theme' hook is run.
 */
add_action( 'after_setup_theme', 'ipushs_setup' );

if ( ! function_exists( 'ipushs_setup' ) ):
/**
 * 設置主題默認和註冊支持各種WordPress的功能。
 *
 * 請注意，此功能，它運行的after_setup_theme鉤上鉤
 * 前的init鉤。的init鉤子是晚了一些功能，如指示
 * 支持後的縮略圖。
 *
 * 覆蓋在一個孩子的主題ipushs_setup（），你的孩子主題的添加自己的ipushs_setup
 * functions.php文件。
 *
 * @用途load_theme_textdomain（）翻譯/本地化支持。
 * @可視化編輯器風格會使用add_editor_style（）。
 * @使用add_theme_support（）添加後的縮略圖，自動進料環節，文章格式的支持。
 * @使用register_nav_menus（）添加支持導航菜單。
 * @使用add_custom_background（）添加支持自定義背景。
 * @使用add_custom_image_header（）添加一個自定義頭的支持。
 * @使用register_default_headers（）來註冊默認的自定義頭提供的圖像與主題。
 * @使用set_post_thumbnail_size（）來設置自定義後縮略圖大小。
 *
 * @since ipushs 1.0
 */
function ipushs_setup() {

	/* Make ipushs available for translation.
	 * Translations can be added to the /languages/ directory.
	 * If you're building a theme based on ipushs, use a find and replace
	 * to change 'ipushs' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'ipushs', get_template_directory() . '/languages' );

	$locale = get_locale();
	$locale_file = get_template_directory() . "/languages/$locale.php";
	if ( is_readable( $locale_file ) )
		require_once( $locale_file );

	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();
	
	/*----ipushs_options初史化----*/
	$options = get_option('ipushs_options');
	// 如果數據庫中不存在該選項組, 設定這些選項的默認值, 並將它們插入數據庫
	if (!is_array($options)) {
		$options['gutterWidth'] = 15;
		$options['articleWidth'] = 258;
		$options['bufferPx'] = 600;
		$options['isAnimated'] = 'false';
		$options['isResizable'] = 'true';
		update_option('ipushs_options', $options);
	}

	// Load up our theme options page and related code.
	require( get_template_directory() . '/inc/theme-options.php' );

	// Add default posts and comments RSS feed links to <head>.
	add_theme_support( 'automatic-feed-links' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', __( 'Primary Menu', 'ipushs' ) );

	// Add support for 自定義背景
	add_custom_background('_ipushs_custom_background');
	function _ipushs_custom_background() 
	{
		$background = get_background_image();
		$color = get_background_color();
		$option_ipushs = get_option('ipushs_options');

	 
		$style = $color ? "background-color: #$color;" : "background: url(".get_template_directory_uri()."/images/bg.jpg);";
	 
		if ( $background ) 
		{
			$image = " background-image: url('$background');";
	 
			$repeat = get_theme_mod( 'background_repeat', 'repeat' );
			if ( ! in_array( $repeat, array( 'no-repeat', 'repeat-x', 'repeat-y', 'repeat' ) ) )
				$repeat = 'repeat';
			$repeat = " background-repeat: $repeat;";
	 
			$position = get_theme_mod( 'background_position_x', 'left' );
			if ( ! in_array( $position, array( 'center', 'right', 'left' ) ) )
				$position = 'left';
			$position = " background-position: top $position;";
	 
			$attachment = get_theme_mod( 'background_attachment', 'scroll' );
			if ( ! in_array( $attachment, array( 'fixed', 'scroll' ) ) )
				$attachment = 'scroll';
			$attachment = " background-attachment: $attachment;";
	 
			$style .= $image . $repeat . $position . $attachment;
		}
		//最後輸出	
		echo "<style type='text/css'>body {".trim( $style )."}</style>";	
	}


	// This theme uses Featured Images (also known as post thumbnails) for per-post/per-page Custom Header images
	add_theme_support( 'post-thumbnails' );

	// The next four constants set how ipushs supports custom headers.






	// We'll be using post thumbnails for custom header images on posts and pages.
	// We want them to be the size of the header image that we just defined
	// Larger images will be auto-cropped to fit, smaller ones will be ignored. See header.php.
	//set_post_thumbnail_size( HEADER_IMAGE_WIDTH, HEADER_IMAGE_HEIGHT, true );

	// Add ipushs's custom image sizes
	//add_image_size( 'large-feature', HEADER_IMAGE_WIDTH, HEADER_IMAGE_HEIGHT, true ); // Used for large feature (header) images
	//add_image_size( 'small-feature', 500, 300 ); // Used for featured posts if a large-feature doesn't exist
	
	// Turn on random header image rotation by default.
	add_theme_support( 'custom-header', array( 'random-default' => true ) );

	// Add a way for the custom header to be styled in the admin panel that controls
	// custom headers. See ipushs_admin_header_style(), below.
	

}
endif; // ipushs_setup






/**
 * 返回“繼續閱讀”摘錄鏈接
 */
function ipushs_continue_reading_link() {
	return ' <a href="'. esc_url( get_permalink() ) . '">' . __( 'Continue reading <span class="meta-nav">&rarr;</span>', 'ipushs' ) . '</a>';
}

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with an ellipsis and ipushs_continue_reading_link().
 *
 * To override this in a child theme, remove the filter and add your own
 * function tied to the excerpt_more filter hook.
 */
function ipushs_auto_excerpt_more( $more ) {
	return ' &hellip;' . ipushs_continue_reading_link();
}
add_filter( 'excerpt_more', 'ipushs_auto_excerpt_more' );

/**
 * Adds a pretty "Continue Reading" link to custom post excerpts.
 *
 * To override this link in a child theme, remove the filter and add your own
 * function tied to the get_the_excerpt filter hook.
 */
function ipushs_custom_excerpt_more( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output .= ipushs_continue_reading_link();
	}
	return $output;
}
add_filter( 'get_the_excerpt', 'ipushs_custom_excerpt_more' );

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
function ipushs_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'ipushs_page_menu_args' );

/**
 * Register our sidebars and widgetized areas. Also register the default Epherma widget.
 *
 * @since ipushs 1.0
 */
function ipushs_widgets_init() {

	
	
	register_sidebar( array(
		'name' => __( 'Single Bottom Sidebar','ipushs' ),
		'id' => 'sidebar-1',
		'description' => __( 'Single Bottom Sidebar','ipushs' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );


}
add_action( 'widgets_init', 'ipushs_widgets_init' );

if ( ! function_exists( 'ipushs_content_nav' ) ) :
/**
 * Display navigation to next/previous pages when applicable
 */
function ipushs_content_nav( $nav_id ) {
	global $wp_query;

	if ( $wp_query->max_num_pages > 1 ) : ?>
		<nav id="<?php echo $nav_id; ?>">
			<h3 class="assistive-text"><?php _e( 'Post navigation', 'ipushs' ); ?></h3>
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'ipushs' ) ); ?></div>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'ipushs' ) ); ?></div>
		</nav><!-- #nav-above -->
	<?php endif;
}
endif; // ipushs_content_nav



if ( ! function_exists( 'ipushs_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own ipushs_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since ipushs 1.0
 */
function ipushs_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'ipushs' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', 'ipushs' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<footer class="comment-meta">
				<div class="comment-author vcard">
					<?php
						$avatar_size = 68;
						if ( '0' != $comment->comment_parent )
							$avatar_size = 39;

						echo get_avatar( $comment, $avatar_size );

						/* translators: 1: comment author, 2: date and time */
						printf( __( '%1$s on %2$s <span class="says">said:</span>', 'ipushs' ),
							sprintf( '<span class="fn">%s</span>', get_comment_author_link() ),
							sprintf( '<a href="%1$s"><time pubdate datetime="%2$s">%3$s</time></a>',
								esc_url( get_comment_link( $comment->comment_ID ) ),
								get_comment_time( 'c' ),
								/* translators: 1: date, 2: time */
								sprintf( __( '%1$s at %2$s', 'ipushs' ), get_comment_date(), get_comment_time() )
							)
						);
					?>

					<?php edit_comment_link( __( 'Edit', 'ipushs' ), '<span class="edit-link">', '</span>' ); ?>
				</div><!-- .comment-author .vcard -->

				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'ipushs' ); ?></em>
					<br />
				<?php endif; ?>

			</footer>

			<div class="comment-content"><?php comment_text(); ?></div>

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply <span>&darr;</span>', 'ipushs' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		</article><!-- #comment-## -->

	<?php
			break;
	endswitch;
}
endif; // ends check for ipushs_comment()

if ( ! function_exists( 'ipushs_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 * Create your own ipushs_posted_on to override in a child theme
 *
 * @since ipushs 1.0
 */
function ipushs_posted_on() {
	printf( __( '<a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s" pubdate>%4$s</time></a>', 'ipushs' ),
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		esc_attr( sprintf( __( 'View all posts by %s', 'ipushs' ), get_the_author() ) ),
		get_the_author()
	);
}
endif;







/*-----數字分頁-----*/
function native_pagenavi(){

    global $wp_query, $wp_rewrite;          
    $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;

    $pagination = array(
      'base' => @add_query_arg('page','%#%'),
      'format' => '',
      'total' => $wp_query->max_num_pages,
      'current' => $current,
	  'prev_next' => True,
      'prev_text' => '上一頁',
      'next_text' => '下一頁'
    );

     if( $wp_rewrite->using_permalinks() )
        $pagination['base'] = user_trailingslashit( trailingslashit( remove_query_arg('s',get_pagenum_link(1) ) ) . 'page/%#%/', 'paged');

     if( !empty($wp_query->query_vars['s']) )
        $pagination['add_args'] = array('s'=>get_query_var('s'));

    echo paginate_links($pagination);
}

/*-----定義上傳圖片縮圖大小-----*/
$option_ipushs = get_option('ipushs_options');
if ( function_exists( 'add_image_size' ) ) 
{ 
	add_image_size( 'ipushs-thumb', $option_ipushs['articleWidth']-8, 9999 );
}


/*-----在wp_head 加入style-----*/
function ipushs_style() {
$option_ipushs = get_option('ipushs_options'); 
?>
<style>
.ipushs article {
	width:<?php echo $option_ipushs['articleWidth'];?>px;
	display:none;
}
</style>
<script>
$(function(){
	$('.ipushs_button').live({
		mouseenter:function(){$(this).css({'background':'#E0E0E0'})},
		mouseleave:function(){$(this).css({'background':'#ccc'})}
	});

	var aritcle = $('.ipushs > article')
	//初始化
		$('.ipushs').masonry({
		// options
		itemSelector : 'article',
		isResizable: <?php echo $option_ipushs['isResizable'];?>,
		isAnimated: <?php echo $option_ipushs['isAnimated'];?>,
		columnWidth : <?php echo $option_ipushs['articleWidth']+20;?>,
		gutterWidth: <?php echo $option_ipushs['gutterWidth'];?>
		});
	 	hljs.tabReplace = '    ';
  		hljs.initHighlightingOnLoad();
		$('.ipushs article').fadeTo(1000, 1)

	//無限捲頁start	
	var $container = $('.ipushs');
	$container.infinitescroll(
	{
		loading: {
			img: "<?php echo get_template_directory_uri(); ?>/images/loading.gif",
			msgText: "<strong>加載中...</strong>",//無限捲頁加載中的訊息
			finishedMsg: "<strong>最後一頁</strong>"//無限捲頁最後顯示的訊息
		},
		navSelector  : "#nav_num_page",            
		nextSelector : "a.page-numbers:last",                
		itemSelector : ".ipushs > article",
		bufferPx	 : <?php echo $option_ipushs['bufferPx']; ?>

	},
	function(newElements)
	{
		var $newElems = $(newElements);
			$container.masonry('appended', $newElems);
			hljs.tabReplace = '    ';
  			hljs.initHighlightingOnLoad();
			$('.ipushs article').fadeTo('4000', 1);
			

	});

	//無限捲頁end
	
	//行動分頁	
	/* toggle nav */
	$("#menu-icon").on("click", function(){
		$("#ipushs_nav").slideToggle();
		$(this).toggleClass("active");	
	});	
	//行動分頁end
});
</script>
<?php
}
add_action( 'wp_head', 'ipushs_style' );





/**
 * Display the post content.
 *
 * @since 0.71
 *
 * @param string $more_link_text Optional. Content for when there is more text.
 * @param bool $stripteaser Optional. Strip teaser content before the more text. Default is false.
 */
function my_the_content($more_link_text = null, $stripteaser = false) {
	$content = my_get_the_content($more_link_text, $stripteaser);
	$content = apply_filters('the_content', $content);
	$content = str_replace(']]>', ']]&gt;', $content);
	echo $content;
}

/**
 * Retrieve the post content.
 *
 * @since 0.71
 *
 * @param string $more_link_text Optional. Content for when there is more text.
 * @param bool $stripteaser Optional. Strip teaser content before the more text. Default is false.
 * @return string
 */
function my_get_the_content($more_link_text = null, $stripteaser = false) {
	global $post, $more, $page, $pages, $multipage, $preview;

	if ( null === $more_link_text )
		$more_link_text = __( '(more...)' );

	$output = '';
	$hasTeaser = false;

	// If post password required and it doesn't match the cookie.
	if ( post_password_required($post) ) {
		$output = get_the_password_form();
		return $output;
	}

	if ( $page > count($pages) ) // if the requested page doesn't exist
		$page = count($pages); // give them the highest numbered page that DOES exist

	$content = $pages[$page-1];
	if ( preg_match('/<!--more(.*?)?-->/', $content, $matches) ) {
		$content = explode($matches[0], $content, 2);
		if ( !empty($matches[1]) && !empty($more_link_text) )
			$more_link_text = strip_tags(wp_kses_no_null(trim($matches[1])));

		$hasTeaser = true;
	} else {
		$content = array($content);
	}
	if ( (false !== strpos($post->post_content, '<!--noteaser-->') && ((!$multipage) || ($page==1))) )
		$stripteaser = true;
	$teaser = $content[0];
	if ( $more && $stripteaser && $hasTeaser )
		$teaser = '';
	$output .= $teaser;
	if ( count($content) > 1 ) {
		if ( $more ) {
			$output .= '<span id="more-' . $post->ID . '"></span>' . $content[1];
		} else {
			if ( ! empty($more_link_text) )
				$output .= apply_filters( 'the_content_more_link', ' <a href="' . get_permalink() . "#more-{$post->ID}\" class=\"more-link ipushs_button\">$more_link_text</a>", $more_link_text );
			$output = force_balance_tags($output);
		}

	}
	if ( $preview ) // preview fix for javascript bug with foreign languages
		$output =	preg_replace_callback('/\%u([0-9A-F]{4})/', '_convert_urlencoded_to_entities', $output);

	$reg = '|[<a]*\s*[^>]*>*<img\s+[^>]*>[</a>]*|is';
	$output = preg_replace($reg, "", $output);
	return $output;
}


/**
 * Get an HTML img element representing an image attachment
 *
 * While $size will accept an array, it is better to register a size with
 * add_image_size() so that a cropped version is generated. It's much more
 * efficient than having to find the closest-sized image and then having the
 * browser scale down the image.
 *
 * @see add_image_size()
 * @uses apply_filters() Calls 'wp_get_attachment_image_attributes' hook on attributes array
 * @uses wp_get_attachment_image_src() Gets attachment file URL and dimensions
 * @since 2.5.0
 *
 * @param int $attachment_id Image attachment ID.
 * @param string $size Optional, default is 'thumbnail'.
 * @param bool $icon Optional, default is false. Whether it is an icon.
 * @return string HTML img element or empty string on failure.
 */
function my_wp_get_attachment_image($attachment_id, $size = 'thumbnail', $icon = false, $attr = '') {

	$html = '';
	$image = wp_get_attachment_image_src($attachment_id, $size, $icon);
	if ( $image ) {
		list($src, $width, $height) = $image;
		$hwstring = image_hwstring($width, $height);
		if ( is_array($size) )
			$size = join('x', $size);
		$attachment =& get_post($attachment_id);
		$default_attr = array(
			'src'	=> $src,
			'class'	=> "attachment-$size",
			'alt'	=> trim(strip_tags( get_post_meta($attachment_id, '_wp_attachment_image_alt', true) )), // Use Alt field first
			'title'	=> trim(strip_tags( $attachment->post_title )),
			'style'=> 'width:'.$width.'px;height:'.$height.'px;',
		);
		if ( empty($default_attr['alt']) )
			$default_attr['alt'] = trim(strip_tags( $attachment->post_excerpt )); // If not, Use the Caption
		if ( empty($default_attr['alt']) )
			$default_attr['alt'] = trim(strip_tags( $attachment->post_title )); // Finally, use the title

		$attr = wp_parse_args($attr, $default_attr);
		$attr = apply_filters( 'wp_get_attachment_image_attributes', $attr, $attachment );
		$attr = array_map( 'esc_attr', $attr );
		$html = rtrim("<img $hwstring");
		foreach ( $attr as $name => $value ) {
			$html .= " $name=" . '"' . $value . '"';
		}
		$html .= ' />';
	}

	return $html;
}

/**
 * Retrieve Post Thumbnail.
 *
 * @since 2.9.0
 *
 * @param int $post_id Optional. Post ID.
 * @param string $size Optional. Image size.  Defaults to 'thumbnail'.
 * @param string|array $attr Optional. Query string or array of attributes.
 */
function my_get_the_post_thumbnail( $post_id = null, $size = 'post-thumbnail', $attr = '' ) {
	$post_id = ( null === $post_id ) ? get_the_ID() : $post_id;
	$post_thumbnail_id = get_post_thumbnail_id( $post_id );
	$size = apply_filters( 'post_thumbnail_size', $size );
	if ( $post_thumbnail_id ) {
		do_action( 'begin_fetch_post_thumbnail_html', $post_id, $post_thumbnail_id, $size ); // for "Just In Time" filtering of all of wp_get_attachment_image()'s filters
		if ( in_the_loop() )
			update_post_thumbnail_cache();
		$html = my_wp_get_attachment_image( $post_thumbnail_id, $size, false, $attr );
		do_action( 'end_fetch_post_thumbnail_html', $post_id, $post_thumbnail_id, $size );
	} else {
		$html = '';
	}
	return apply_filters( 'post_thumbnail_html', $html, $post_id, $post_thumbnail_id, $size, $attr );
}


/**
 * Display Post Thumbnail.
 *
 * @since 2.9.0
 *
 * @param int $size Optional. Image size.  Defaults to 'post-thumbnail', which theme sets using set_post_thumbnail_size( $width, $height, $crop_flag );.
 * @param string|array $attr Optional. Query string or array of attributes.
 */
function my_the_post_thumbnail( $size = 'post-thumbnail', $attr = '' ) {
	echo my_get_the_post_thumbnail( null, $size, $attr );
}


//設定youtube wmode
function add_video_wmode_transparent($html, $url, $attr) {

if ( strpos( $html, "<embed src=" ) !== false )
   { return str_replace('</param><embed', '</param><param name="wmode" value="opaque"></param><embed wmode="opaque" ', $html); }
elseif ( strpos ( $html, 'feature=oembed' ) !== false )
   { return str_replace( 'feature=oembed', 'feature=oembed&wmode=opaque', $html ); }
else
   { return $html; }
}
add_filter( 'embed_oembed_html', 'add_video_wmode_transparent', 10, 3);